==> istio-model-v1beta1-6.2.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/WorkloadEntryListFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface WorkloadEntryListFluent<A extends WorkloadEntryListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,WorkloadEntry item);
  public A setToItems(Integer index,WorkloadEntry item);
  public A addToItems(io.fabric8.istio.api.networking.v1beta1.WorkloadEntry... items);
  public A addAllToItems(Collection<WorkloadEntry> items);
  public A removeFromItems(io.fabric8.istio.api.networking.v1beta1.WorkloadEntry... items);
  public A removeAllFromItems(Collection<WorkloadEntry> items);
  public A removeMatchingFromItems(Predicate<WorkloadEntryBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<WorkloadEntry> getItems();
  public List<WorkloadEntry> buildItems();
  public WorkloadEntry buildItem(Integer index);
  public WorkloadEntry buildFirstItem();
  public WorkloadEntry buildLastItem();
  public WorkloadEntry buildMatchingItem(Predicate<WorkloadEntryBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<WorkloadEntryBuilder> predicate);
  public A withItems(List<WorkloadEntry> items);
  public A withItems(io.fabric8.istio.api.networking.v1beta1.WorkloadEntry... items);
  public Boolean hasItems();
  public WorkloadEntryListFluent.ItemsNested<A> addNewItem();
  public WorkloadEntryListFluent.ItemsNested<A> addNewItemLike(WorkloadEntry item);
  public WorkloadEntryListFluent.ItemsNested<A> setNewItemLike(Integer index,WorkloadEntry item);
  public WorkloadEntryListFluent.ItemsNested<A> editItem(Integer index);
  public WorkloadEntryListFluent.ItemsNested<A> editFirstItem();
  public WorkloadEntryListFluent.ItemsNested<A> editLastItem();
  public WorkloadEntryListFluent.ItemsNested<A> editMatchingItem(Predicate<WorkloadEntryBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,WorkloadEntryFluent<WorkloadEntryListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/WorkloadEntryListFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface WorkloadEntryListFluent<A extends WorkloadEntryListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,WorkloadEntry item);
  public A setToItems(int index,WorkloadEntry item);
  public A addToItems(io.fabric8.istio.api.networking.v1beta1.WorkloadEntry... items);
  public A addAllToItems(Collection<WorkloadEntry> items);
  public A removeFromItems(io.fabric8.istio.api.networking.v1beta1.WorkloadEntry... items);
  public A removeAllFromItems(Collection<WorkloadEntry> items);
  public A removeMatchingFromItems(Predicate<WorkloadEntryBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<WorkloadEntry> getItems();
  public List<WorkloadEntry> buildItems();
  public WorkloadEntry buildItem(int index);
  public WorkloadEntry buildFirstItem();
  public WorkloadEntry buildLastItem();
  public WorkloadEntry buildMatchingItem(Predicate<WorkloadEntryBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<WorkloadEntryBuilder> predicate);
  public A withItems(List<WorkloadEntry> items);
  public A withItems(io.fabric8.istio.api.networking.v1beta1.WorkloadEntry... items);
  public Boolean hasItems();
  public WorkloadEntryListFluent.ItemsNested<A> addNewItem();
  public WorkloadEntryListFluent.ItemsNested<A> addNewItemLike(WorkloadEntry item);
  public WorkloadEntryListFluent.ItemsNested<A> setNewItemLike(int index,WorkloadEntry item);
  public WorkloadEntryListFluent.ItemsNested<A> editItem(int index);
  public WorkloadEntryListFluent.ItemsNested<A> editFirstItem();
  public WorkloadEntryListFluent.ItemsNested<A> editLastItem();
  public WorkloadEntryListFluent.ItemsNested<A> editMatchingItem(Predicate<WorkloadEntryBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,WorkloadEntryFluent<WorkloadEntryListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
